@@ -70,7 +70,7 @@ zcurve       <- function(z, p, method = "EM", bootstrap = 1000, control = NULL){
   if(!missing(z)){
     if(!is.numeric(z))stop("Wrong z-scores input: Data are not nummeric.")
     if(!is.vector(z))stop("Wrong z-scores input: Data are not a vector")
-    if(max(z) < 1 )stop("It looks like you are entering p-values rather than Z-scores. To use p-values, explicitly name your argument 'zcurve(p = [vector of p-values])'")
+    if(all(z <= 1 & z >= 0))stop("It looks like you are entering p-values rather than z-scores. To use p-values, explicitly name your argument 'zcurve(p = [vector of p-values])'")
     input_type <- c(input_type, "z")
   }else{
     z <- NULL
